# -*- coding: utf-8 -*-
"""
Created on Mon Aug 17 08:58:06 2020

@author: Inga Kuznetsova
"""

from .Park_test import Park_test
from .Glejser import Glejser_test